<p align="center">
  <img width="491" alt="basata" src="https://github.com/sg-tarek/BASATA/blob/main/logo.png?raw=true">
</p>

[![Python](https://img.shields.io/badge/Python-3-blue)](https://badge.fury.io/py/basata) 
[![PyPI version](https://badge.fury.io/py/basata.svg)](https://badge.fury.io/py/basata) 
[![License](https://img.shields.io/pypi/l/ansicolortags.svg)](https://img.shields.io/pypi/l/ansicolortags.svg) 

BASATA is the Arabic word for simplicity. The purpose of the BASATA library is to simplify coding while providing profound insights. You can use BASATA to write code that is easy to read, understand, and maintain.

The BASATA library is used to automate machine learning tasks. Building on the spirit of AutoML, BASATA is a framework for analysing data and building machine learning models.

The library has been tested on reel use cases and will be the number one tool for professional Data Scientists.

The current version supports supervised machine learning and will be expanded to unsupervised followed by Time Series analysis. The project is open source and will grow through contributions by its users.

Official Documentation: https://sg-tarek.github.io/

Installing
============

    pip install basata

Usage
=====

    from basata.supervised import *

Upgrade
=====

    pip install --upgrade basata

or

    pip install --upgrade basata==<VERSION_NUMBER>


## License
BASATA is completely free and open-source and licensed under the [MIT](https://github.com/sg-tarek/BASATA/blob/main/LICENSE.txt) license. 

## Contributors
<a href="https://github.com/sg-tarek/BASATA/graphs/contributors">
  <img src="https://contributors-img.web.app/image?repo=sg-tarek/BASATA" width = 100/>
</a>